==> mediathekview-13.5.1-3-any.pkg.tar.xz: usr/share/doc/mediathekview/README.md <==

[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
[![Build Status](https://travis-ci.org/mediathekview/MediathekView.svg?branch=master)](https://travis-ci.org/mediathekview/MediathekView)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=mediathekview_MediathekView&metric=alert_status)](https://sonarcloud.io/dashboard?id=mediathekview_MediathekView)

# MediathekView
Das Programm **MediathekView** durchsucht die Mediatheken verschiedener überwiegend deutschsprachiger öffentlich-rechtlicher Sender, lädt Beiträge daraus herunter oder spielt diese ab (mit [VLC Media Player](https://videolan.org/vlc/) oder mit einem Programm eigener Wahl). Es können auch Sendereihen/Serien abonniert werden.

## Sender
Derzeit werden die Mediatheken der folgenden Sender unterstützt:

- ARD (Das Erste)
   - BR (Bayerischer Rundfunk)
   - HR (Hessischer Rundfunk)
   - MDR (Mitteldeutscher Rundfunk)
   - NDR (Norddeutscher Rundfunk)
   - RBB (Rundfunk Berlin-Brandenburg)
   - SR (Saarländischer Rundfunk)
   - SWR (Südwestrundfunk)
   - WDR (Westdeutscher Rundfunk)
- ZDF (Zweites Deutsches Fernsehen) inkl. Tivi
   - Phoenix
   - Kika (Kinderkanal von ARD und ZDF)
   - 3Sat
   - Arte (deutsch und französisch)
- DW TV (Deutsche Welle)
- ORF (Österreichischer Rundfunk)
- SRF (Schweizer Rundfunk) inkl. Podcasts

# Links
- [Webseite](https://mediathekview.de)
- [Download](https://mediathekview.de/download/)
- [Wiki](https://github.com/mediathekview/MediathekView/wiki)
- [Forum](https://forum.mediathekview.de/)
- [Anleitung](https://mediathekview.de/anleitung/)
- [FAQ](https://mediathekview.de/faq/)

# [Entwicklung](https://github.com/mediathekview/MediathekView/wiki/Entwicklung)
Siehe / See: [Wiki | Entwicklung](https://github.com/mediathekview/MediathekView/wiki/Entwicklung)

==> mediathekview-13.6.0-2-any.pkg.tar.xz: usr/share/doc/mediathekview/README.md <==

[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
[![Build Status](https://travis-ci.com/mediathekview/MediathekView.svg?branch=master)](https://travis-ci.com/mediathekview/MediathekView)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=mediathekview_MediathekView&metric=alert_status)](https://sonarcloud.io/dashboard?id=mediathekview_MediathekView)

# MediathekView
Das Programm **MediathekView** durchsucht die Mediatheken verschiedener überwiegend deutschsprachiger öffentlich-rechtlicher Sender, lädt Beiträge daraus herunter oder spielt diese ab (mit [VLC Media Player](https://videolan.org/vlc/) oder mit einem Programm eigener Wahl). Es können auch Sendereihen/Serien abonniert werden.

## Sender
Derzeit werden die Mediatheken der folgenden Sender unterstützt:

- ARD (Das Erste)
   - BR (Bayerischer Rundfunk)
   - HR (Hessischer Rundfunk)
   - MDR (Mitteldeutscher Rundfunk)
   - NDR (Norddeutscher Rundfunk)
   - RBB (Rundfunk Berlin-Brandenburg)
   - SR (Saarländischer Rundfunk)
   - SWR (Südwestrundfunk)
   - WDR (Westdeutscher Rundfunk)
- ZDF (Zweites Deutsches Fernsehen) inkl. Tivi
   - Phoenix
   - Kika (Kinderkanal von ARD und ZDF)
   - 3Sat
   - Arte (deutsch und französisch)
- DW TV (Deutsche Welle)
- ORF (Österreichischer Rundfunk)
- SRF (Schweizer Rundfunk) inkl. Podcasts

# Links
- [Webseite](https://mediathekview.de)
- [Download](https://mediathekview.de/download/)
- [Wiki](https://github.com/mediathekview/MediathekView/wiki)
- [Forum](https://forum.mediathekview.de/)
- [Anleitung](https://mediathekview.de/anleitung/)
- [FAQ](https://mediathekview.de/faq/)

# [Entwicklung](https://github.com/mediathekview/MediathekView/wiki/Entwicklung)
Siehe / See: [Wiki | Entwicklung](https://github.com/mediathekview/MediathekView/wiki/Entwicklung)
